@@ -17,7 +17,7 @@ Claws Mail lightweight email client
 all
 </installable>
 
-<screenshot>https://screenshots.debian.net/screenshots/000/004/963/large.png</screenshot>
+<screenshot>none</screenshot>
 
 <preinstall>
 
